;;********************************************************************
;;********************************************************************
;;  ADCINC12int.asm
;;
;;  Assembler source for interrupt routines the 12 bit Incremential
;;  A/D converter.
;;
;;  Rev C, 2001 Oct 2
;;
;;  Copyright: Cypress MicroSystems 2000,2001.  All Rights Reserved.
;;
;;*********************************************************************
;;*********************************************************************

export  ADCINC12_1_CNT_INT
export  ADCINC12_1_TMR_INT
include "ADCINC12_1.inc"
include "m8c.inc"

area bss(RAM) 
    ADCINC12_1_cTimerU:   BLK  1   ;The Upper byte of the Timer
    ADCINC12_1_cCounterU: BLK  1   ;The Upper byte of the Counter
   _ADCINC12_1_iIncr:
    ADCINC12_1_iIncr:     BLK  2   ;A/D value
   _ADCINC12_1_fIncr:
    ADCINC12_1_fIncr:     BLK  1   ;Data Valid Flag
    ADCINC12_1_bIncrC:    BLK  1   ;# of times to run A/D

area text(ROM,REL)

 export  ADCINC12_1_cTimerU
 export  ADCINC12_1_cCounterU
 export _ADCINC12_1_iIncr
 export  ADCINC12_1_iIncr
 export _ADCINC12_1_fIncr
 export  ADCINC12_1_fIncr
 export  ADCINC12_1_bIncrC

LowByte:   equ 1
HighByte:  equ 0

 
;;------------------------------------------------------------------
;;  CNT_INT:
;;  Increment  the upper (software) half on the counter whenever the
;;  lower (hardware) half of the counter underflows.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
ADCINC12_1_CNT_INT:
   inc [ADCINC12_1_cCounterU]
   reti

;;------------------------------------------------------------------
;;  TMR_INT:
;;  This routine allows the counter to collect data for 64 timer cycles
;;  This routine then holds the integrater in reset for one cycle while
;;  the A/D value is calculated.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
ADCINC12_1_TMR_INT:
   dec [ADCINC12_1_cTimerU]
;  if(upper count >0 )
   jz  else1
      reti
   else1:;(upper count decremented to 0)
      tst reg[ADCINC12_1_AtoDcr3],10h
      jz   else2
;     if(A/D has been in reset mode)
         mov reg[ADCINC12_1_CounterCR0],01h   ; Enable Counter
         and reg[ADCINC12_1_AtoDcr3],~10h     ; Enable Analog Integrator
IF ADCINC12_1_NoAZ
         and reg[ADCINC12_1_AtoDcr2],~20h
ENDIF
         mov [ADCINC12_1_cTimerU],(1<<(ADCINC12_1_NUMBITS - 6))
                                                    ; This will be the real counter value
         reti
      else2:;(A/D has been in integrate mode)
         mov reg[ADCINC12_1_CounterCR0],00h   ;disable counter
         or  F,01h                                  ;Enable the interrupts
         ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
         ; Good place to add code to switch inputs for multiplexed input to ADC
         ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
IF ADCINC12_1_NoAZ
         or  reg[ADCINC12_1_AtoDcr2],20h      ;Reset Integrator
ENDIF
         or  reg[ADCINC12_1_AtoDcr3],10h
         push A
         mov A, reg[ADCINC12_1_CounterDR0]    ;read Counter
         mov A, reg[ADCINC12_1_CounterDR2]    ;now you really read the data
         cpl A
         cmp [ADCINC12_1_cCounterU],(1<<(ADCINC12_1_NUMBITS - 7))
         jnz endif10
;        if(max positive value)
            dec [ADCINC12_1_cCounterU]
            mov A,ffh
         endif10:
         asr [ADCINC12_1_cCounterU]                              ; divide by 4
         rrc A
         asr [ADCINC12_1_cCounterU]
         rrc A
;
         mov [(ADCINC12_1_iIncr + HighByte)],[ADCINC12_1_cCounterU]
         mov [(ADCINC12_1_iIncr + LowByte)],A
         mov [ADCINC12_1_fIncr],01h          ;Set AD data flag
         pop A
         ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
         ; User code here for interrupt system.
         ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
         cmp [ADCINC12_1_bIncrC],00h
         jz  endif3
;        if(ADCINC12_1_bIncrC is not zero)
            dec [ADCINC12_1_bIncrC]
            jnz endif4
;           if(ADCINC12_1_bIncrC has decremented down to zero to 0)
               mov reg[ADCINC12_1_TimerCR0],00h          ;disable the Timer
               mov reg[ADCINC12_1_CounterCR0],00h        ;disable the Counter
               nop
               nop
               and reg[INT_MSK1],~(ADCINC12_1_TimerMask | ADCINC12_1_CounterMask)
                                                               ;Disable both interrupts
IF ADCINC12_1_NoAZ
               or  reg[ADCINC12_1_AtoDcr2],20h           ;Reset Integrator
ENDIF
               or  reg[ADCINC12_1_AtoDcr3],10h
               reti
            endif4:;
         endif3:;
      endif2:;
      mov [ADCINC12_1_cTimerU],1                         ;Set Timer for one cycle of reset
      mov [ADCINC12_1_cCounterU],(-(1<<(ADCINC12_1_NUMBITS - 7))) ;Set Counter hardware for easy enable
      mov reg[ADCINC12_1_CounterDR1],ffh 
      reti
   endif1:;

ADCINC12_1_APIINT_END:
