;;********************************************************************
;;********************************************************************
;;  ADCINC12.asm
;;
;;  Assembler source for the 12 bit Incremential A/D converter.
;;
;;  REV D, 2002 MAR 30
;;
;;  Copyright: Cypress MicroSystems 2000-2002.  All Rights Reserved.
;;
;;*********************************************************************
;;*********************************************************************

export  ADCINC12_1_Start
export _ADCINC12_1_Start
export  ADCINC12_1_SetPower
export _ADCINC12_1_SetPower
export  ADCINC12_1_Stop
export _ADCINC12_1_Stop
export  ADCINC12_1_GetSamples
export _ADCINC12_1_GetSamples
export  ADCINC12_1_StopAD
export _ADCINC12_1_StopAD
export  ADCINC12_1_fIsData
export _ADCINC12_1_fIsData
export  ADCINC12_1_iGetData
export _ADCINC12_1_iGetData
export  ADCINC12_1_ClearFlag
export _ADCINC12_1_ClearFlag

include "ADCINC12_1.inc"
include "m8c.inc"

LowByte:   equ 1
HighByte:  equ 0


;;------------------------------------------------------------------
;;  Start:
;;  SetPower:
;;  Applies power setting to the module's analog PSoc block.
;;  INPUTS:  A contains the power setting
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 ADCINC12_1_Start:
_ADCINC12_1_Start:
 ADCINC12_1_SetPower:
_ADCINC12_1_SetPower:
   push X            ;save X
   mov  X,SP	   ;X will point at next pushed value
   and  A,03h
   push A		   ;X points at copy of A
   mov  A,reg[ADCINC12_1_AtoDcr3]
   and  A,~03h       ;clear power bits
   or   A,[ X ]
   mov  reg[ADCINC12_1_AtoDcr3],A
   pop  A
   pop  X
   ret

;;------------------------------------------------------------------
;;  Stop:
;;  SetPower:
;;  Removes power from the module's analog PSoc block.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 ADCINC12_1_Stop:
_ADCINC12_1_Stop:
   and reg[ADCINC12_1_AtoDcr3], ~03h
   ret

;;------------------------------------------------------------------
;;  Get_Samples:
;;  SetPower:
;;  Starts the A/D convertor and will place data is memory.  A flag
;;  is set whenever a new data value is available.
;;  INPUTS:  A passes the number of samples (0 is continous).
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 ADCINC12_1_GetSamples:
_ADCINC12_1_GetSamples:
   mov [ADCINC12_1_bIncrC],A	      ;number of samples
   or  reg[INT_MSK1],(ADCINC12_1_TimerMask | ADCINC12_1_CounterMask )
                                          ;Enable both interrupts
   mov [ADCINC12_1_cTimerU],1       ;Force the Timer to do one cycle of rest
IF ADCINC12_1_NoAZ
   or  reg[ADCINC12_1_AtoDcr2],20h  ;force the Integrator into reset
ENDIF
   or  reg[ADCINC12_1_AtoDcr3],10h
   mov [ADCINC12_1_cCounterU],(-(1<<(ADCINC12_1_NUMBITS - 7)));Initialize Counter
   mov reg[ADCINC12_1_TimerDR1],ffh
   mov reg[ADCINC12_1_CounterDR1],ffh
   mov reg[ADCINC12_1_TimerCR0],01h ;enable the Timer
   mov [ADCINC12_1_fIncr],00h       ;A/D Data Ready Flag is reset
   ret

;;------------------------------------------------------------------
;;  StopAD:
;;  Completely shuts down the A/D is an orderly manner.  Both the
;;  Timer and COunter interrupts are disabled.
;;  INPUTS:  None.
;;  OUTPUTS: None.  
;;------------------------------------------------------------------
 ADCINC12_1_StopAD:
_ADCINC12_1_StopAD:
   mov reg[ADCINC12_1_TimerCR0],00h       ;disable the Timer
   mov reg[ADCINC12_1_CounterCR0],00h     ;disable the Counter
   nop
   nop
   ;Disable both interrupts
   M8C_DisableIntMask INT_MSK1, (ADCINC12_1_TimerMask | ADCINC12_1_CounterMask )
IF ADCINC12_1_NoAZ
   or  reg[ADCINC12_1_AtoDcr2],20h        ;reset Integrator
ENDIF
   or  reg[ADCINC12_1_AtoDcr3],10h
   ret
;;------------------------------------------------------------------
;;  fIsData:
;;  Returns the status of the A/D Data
;;  is set whenever a new data value is available.
;;  INPUTS:  None.
;;  OUTPUTS: A returned data status A =: 0 no data available
;;                                   !=: 0 data available.  
;;------------------------------------------------------------------
 ADCINC12_1_fIsData:
_ADCINC12_1_fIsData:
   mov A,[ADCINC12_1_fIncr]
   ret

;;------------------------------------------------------------------
;;  iGetData:
;;  Returns the data from the A/D.  Does not check if data is
;;  available.
;;  is set whenever a new data value is available.
;;  INPUTS:  None.
;;  OUTPUTS: X:A returns the A/D data value.  
;;------------------------------------------------------------------
 ADCINC12_1_iGetData:
_ADCINC12_1_iGetData:
   mov X,[(ADCINC12_1_iIncr + HighByte)]
   mov A,[(ADCINC12_1_iIncr + LowByte)]
   ret

;;------------------------------------------------------------------
;;  ClearFlag:
;;  clears the data ready flag.
;;  INPUTS:  None.
;;  OUTPUTS: None.
;;------------------------------------------------------------------
 ADCINC12_1_ClearFlag:
_ADCINC12_1_ClearFlag:
   mov [ADCINC12_1_fIncr],00h
   ret

ADCINC12_1_API_End:
	
